/*
 * Copyright (C) 2003 David Sansome <david@dave.sanspic.net>
 */

#ifndef _MUTRAY_H_
#define _MUTRAY_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kapplication.h>
#include <kmainwindow.h>
#include <qnetworkprotocol.h>
#include <qurloperator.h>
#include <kprogress.h>
#include <kio/jobclasses.h>
#include <ksystemtray.h>
#include <rpm/rpmlib.h>
#include <qtimer.h>
#include <qprocess.h>

#include "updatelist.h"

class KToggleAction;

struct Update
{
	QStringList packagesAffected;
	QString date;
	int importance;
	QString reason;
	QString description;
};


class MUApplication : public KApplication
{
public:
	MUApplication() {shuttingDown=false;}
	bool shuttingDown;

private:
	void commitData(QSessionManager &sm) {shuttingDown=true; KApplication::commitData(sm);}
};


class MUMain : public KMainWindow
{
	Q_OBJECT
public:
	MUMain();
	virtual ~MUMain();


protected:
	void save();
	void load();


private slots:
	void optionsShowStatusbar();
	void optionsConfigureKeys();
	void optionsPreferences();
	void closeEvent(QCloseEvent *e);

	void checkNow();
	void descriptionsFinished( KIO::Job *);
	void listFinished( KIO::Job *);
	void download();

	void updateMirrorList() {updateMirrorList(false);}
	void updateMirrorList(bool random);
	void dataReceived(const QByteArray & datar, QNetworkOperation * );
	void dataTransferProgress(int done, int total, QNetworkOperation * );
	void mirrorListFinished( KIO::Job *);
	void newChildren(KIO::Job*,const KIO::UDSEntryList&);

	void showDetails(QListViewItem* item, bool uptodate=false);
	void popupMenu(QListViewItem*,const QPoint&,int);
	void toggleIgnore();

	void toggleIcon();

	void aMinuteHasPassed();

	void downloadFinished();
	void readyReadStdout();


signals:
	void mirrorListChanged();


private:
	void setupAccel();
	void setupActions();
	void processMirrorList();
	void removePackage(QString name);
	void showEvent ( QShowEvent * );
	bool verCmp(QString a, QString b);

	int importance(QString a)
	{
		if (a=="Security fixes") return 2;
		if (a=="Bug fixes") return 1;
		return 0;
	}
	QString importance(int a)
	{
		if (a==2) return "Security fixes";
		if (a==1) return "Bug fixes";
		return "Normal updates";
	}

	bool timeToUpdate()
	{
		if (!autoCheck) return false;
		QDateTime nextCheck = lastCheck;
		if (autoType == 2) nextCheck = nextCheck.addDays(autoInterval);
		if (autoType == 1) nextCheck = nextCheck.addSecs(autoInterval*60*60);
		if (autoType == 0) nextCheck = nextCheck.addSecs(autoInterval*60);
		if (QDateTime::currentDateTime() >= nextCheck) return true;
		return false;
	}


private:
	UpdateList* view;
	QUrlOperator* url;
	QString data;
	rpmdb dbp;
	QPtrList<Update> updates;
	bool busy;
	bool randomMirror;
	int retryCount;
	int notFoundCount;

	KProgress* progressBar;

	KToggleAction *m_statusbarAction;

	QPixmap packageIcon;
	QPixmap greyPackageIcon;
	QPixmap folderIcon;
	QPixmap redFolderIcon;
	QPixmap trayIcon;
	QPixmap trayActiveIcon;
	int trayIconType;
	KSystemTray* tray;
	QTimer* iconToggleTimer;

	QTimer* minuteTimer;
	QDateTime lastCheck;

	QStringList ignoredPackages;

	QProcess* updateScript;


public:  // These are public because i'm too lazy to do Get and Set functions for them
	QString currentMirror;
	QStringList mirrorList;
	QString distro;
	bool autoCheck;
	int autoInterval;
	int autoType;
	bool notifyOnSecurity;
	bool notifyOnBug;
	bool notifyOnNormal;


};

#endif // _MUTRAY_H_
