/*
 * Copyright (C) 2003 David Sansome <david@dave.sanspic.net>
 */

#include "pref.h"
#include "mutray.h"

#include <klocale.h>

#include <qlayout.h>
#include <qlistview.h>
#include <qmessagebox.h>
#include <qlabel.h>
#include <qcheckbox.h>
#include <qspinbox.h>
#include <qcombobox.h>

MUPreferences::MUPreferences(MUMain* parent)
    : KDialogBase(TreeList, i18n("MandrakeUpdate-Tray Preferences"),
                  Help|Default|Ok|Apply|Cancel, Ok)
{
    main = parent;
    // this is the base class for your preferences dialog.  it is now
    // a Treelist dialog.. but there are a number of other
    // possibilities (including Tab, Swallow, and just Plain)

    QVBox* vbox = addVBoxPage(i18n("Notifications"), i18n("Configure notifications"));
    notificationsConf = new NotificationsConf((QWidget*)vbox);
    notificationsConf->setBoxes(parent->autoCheck,parent->autoInterval,parent->autoType,parent->notifyOnSecurity,parent->notifyOnBug,parent->notifyOnNormal);

    vbox = addVBoxPage(i18n("Mirrors"), i18n("Mirror selection"));
    mirrorsConf = new MirrorsConf((QWidget*)vbox);
    mirrorListChanged();
    connect(mirrorsConf,SIGNAL(updateList()),parent,SLOT(updateMirrorList()));
    connect(parent,SIGNAL(mirrorListChanged()),SLOT(mirrorListChanged()));
}

void MUPreferences::mirrorListChanged()
{
	mirrorsConf->setList(main->mirrorList,main->currentMirror);
}

void MUPreferences::slotOk()
{
	slotApply();
	accept();
}

void MUPreferences::slotApply()
{
	if (mirrorsConf->list->childCount() != 0)
	{
		if (mirrorsConf->list->currentItem()->parent())
			main->currentMirror = mirrorsConf->list->currentItem()->text(0);
	}
	main->autoCheck = notificationsConf->autoBox->isChecked();
	main->autoInterval = notificationsConf->intervalBox->value();
	main->autoType = notificationsConf->typeBox->currentItem();
	main->notifyOnSecurity = notificationsConf->securityBox->isChecked();
	main->notifyOnBug = notificationsConf->bugBox->isChecked();
	main->notifyOnNormal = notificationsConf->normalBox->isChecked();
}

#include "pref.moc"
